@@ -1,8 +1,6 @@
 // RegisteringDynamic Symbols
 
-#include <R.h>
 #include <Rinternals.h>
-#include <R_ext/Rdynload.h>
 
 void R_init_brunnermunzel(DllInfo* info) {
   R_registerRoutines(info, NULL, NULL, NULL, NULL);
